#
# spec file for package weechat
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           weechat
Version:        2.1
Release:        lp151.2.5
Summary:        Multi-protocol extensible Chat Client
License:        GPL-3.0+
Group:          Productivity/Networking/IRC
URL:            http://weechat.org
Source:         http://weechat.org/files/src/%{name}-%{version}.tar.xz
Source1:        weechat.desktop
Source2:        %{name}.keyring
Source3:        http://weechat.org/files/src/%{name}-%{version}.tar.xz.asc
Source4:        %{name}.changes
BuildRequires:  ca-certificates
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  gcc-c++
BuildRequires:  grep
BuildRequires:  hicolor-icon-theme
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libtool
BuildRequires:  lzo-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  ruby-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(enchant)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(guile-2.0)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(tcl)
Requires:       ca-certificates
Requires:       hicolor-icon-theme
Recommends:     %{name}-lang = %{version}
# without scripts it is bit annoying
Recommends:     %{name}-perl = %{version}
Recommends:     %{name}-python = %{version}

%description
WeeChat (Wee Enhanced Environment for Chat) is a
chat environment. It can be entirely controlled with the keyboard, has a
plugin-based architecture and is customizable and extensible with scripts in
several scripting languages.

%lang_package

%package devel
Summary:        Development Environment for %{name} Plugins
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development environment for authoring %{name} plugins.

%package guile
Summary:        Guile Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description guile
Support for %{name} scripts written in the Guile language.

%package lua
Summary:        Lua Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description lua
Support for %{name} scripts written in the Lua language.

%package perl
Summary:        Perl Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}
%{?libperl_requires}

%description perl
Support for %{name} scripts written in the Perl language.

%package python
Summary:        Python Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description python
Support for %{name} scripts written in the Python language.

%package tcl
Summary:        Tcl Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description tcl
Support for %{name} scripts written in the Tcl language.

%package ruby
Summary:        Ruby Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description ruby
Support for %{name} scripts written in the Ruby language.

%package aspell
Summary:        Aspell Spell-Checking Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description aspell
Spell-checking support for %{name}, using the aspell library.

%prep
%setup -q
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE4}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find . -name '*.[ch]' -exec sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" "{}" "+"

%build
export CFLAGS="%{optflags}"
# Tests require cpputest package
# no-undefined for perl seem not to work as desired
%cmake \
    -DLIBDIR="%{_libdir}" \
    -DENABLE_PYTHON3=ON \
    -DPYTHON_LIBRARY="%{_libdir}/libpython%{py3_ver}m.so" \
    -DENABLE_ENCHANT=ON \
    -DCA_FILE=%{_sysconfdir}/ssl/ca-bundle.pem
%make_jobs

%install
%cmake_install

install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%suse_update_desktop_file -r "%{name}" Network IRCClient

%find_lang "%{name}" --with-man



%files
%doc AUTHORS.adoc ChangeLog.adoc Contributing.adoc
%doc README.adoc ReleaseNotes.adoc
%license COPYING
%{_bindir}/weechat-curses
%{_bindir}/weechat-headless
%{_bindir}/weechat
%dir %{_libdir}/weechat
%dir %{_libdir}/weechat/plugins
%{_libdir}/weechat/plugins/alias.so
%{_libdir}/weechat/plugins/buflist.so
%{_libdir}/weechat/plugins/charset.so
%{_libdir}/weechat/plugins/exec.so
%{_libdir}/weechat/plugins/fifo.so
%{_libdir}/weechat/plugins/irc.so
%{_libdir}/weechat/plugins/logger.so
%{_libdir}/weechat/plugins/relay.so
%{_libdir}/weechat/plugins/script.so
%{_libdir}/weechat/plugins/trigger.so
%{_libdir}/weechat/plugins/xfer.so
%{_libdir}/weechat/plugins/fset.so
%{_datadir}/applications/weechat.desktop
%{_datadir}/icons/hicolor/*/apps/weechat.png

%files -f "%{name}.lang" lang

%files devel
%{_includedir}/weechat
%{_libdir}/pkgconfig/weechat.pc

%files guile
%{_libdir}/weechat/plugins/guile.so

%files lua
%{_libdir}/weechat/plugins/lua.so

%files perl
%{_libdir}/weechat/plugins/perl.so

%files python
%{_libdir}/weechat/plugins/python.so

%files tcl
%{_libdir}/weechat/plugins/tcl.so

%files ruby
%{_libdir}/weechat/plugins/ruby.so

%files aspell
%{_libdir}/weechat/plugins/aspell.so

%changelog
* Mon Mar 19 2018 jengelh@inai.de
- Ensure neutrality of description.
- Use -exec over xargs.
* Mon Mar 19 2018 mimi.vx@gmail.com
- update to 2.1
- build python plugin against python3
  * core: add binary weechat-headless to run WeeChat without interface, with
  optional daemon mode (command line option "--daemon")
  * core: add options "-newbuffer", "-free" and "-switch" in command /print
  * core: add option "-y" in command /print, add support of buffers with free content
  * core: add option "add" in command /buffer
  * core: add option weechat.completion.partial_completion_templates to force
    partial completion on specific templates
  * api: add hashtable with variables in plugin structure
  * irc: add server option "split_msg_max_length"
  * logger: add option logger.file.fsync
  * logger: add option logger.look.backlog_conditions)
  * scripts: add configuration file for each script plugin
  * scripts: add "eval" option in script commands and info "xxx_eval"
  * scripts: add infos "xxx_interpreter" and "xxx_version" in script plugins
  * scripts: add option "version" in script commands
  * api: add time in info "date" (WeeChat compilation date/time)
  * irc: allow ${irc_server.xxx} and ${server} in server evaluated options
  * script: change default value of option script.look.sort from "p,n" to "i,p,n"
  * scripts: display the script name in stdout/stderr output from scripts
  * core: fix regression on execution of hook_print callbacks
* Thu Dec 21 2017 mimi.vx@gmail.com
- update to 2.0.1
  * python: fix arguments status/gnutls_rc/sock in hook_connect() callback
  * python: fix argument fd in hook_fd() callback
  * core: add flag "input_get_empty" in buffer
  * core: add signals "buffer_filters_enabled" and "buffer_filters_disabled"
  * core: support loading of plugins from path in environment
    variable "WEECHAT_EXTRA_LIBDIR"
  * alias: add infolist "alias_default" (list of default aliases)
  * buflist: add two new bar items ("buflist2" and "buflist3") using the same
    format configuration options
  * buflist: add option buflist.look.add_newline
  * fset: new plugin "fset" (fast set of WeeChat and plugins options)
  * core: make value optional in command /buffer set
  * core: allow floating point and hexadecimal numbers in comparison of evaluated values
  * core: add option weechat.look.save_config_with_fsync
  * api: add support of prefix "quiet:" in function key_unbind() to quietly remove keys
  * api: add argument "recurse_subdirs" in function exec_on_files()
  * script: add local variable "filter" in the script buffer
  * core: do not change the chat prefix size when a filtered line is added
  * core: fix display of nicks in nicklist when they are in a group with sub-groups
  * core, plugins: check return code of strftime function
  * core: fix cast of time_t (to "long long" instead of "long")
  * core: call the config hook when options are renamed or removed
  * api: change type of arguments status/gnutls_rc/sock in hook_connect() callback
    from string to integer (in scripts)
  * api: change type of argument fd in hook_fd() callback from
    string to integer (in scripts)
  * buflist: remove recursive evaluation of extra variables
  * guile: return integer (0/1) instead of boolean in API functions
  * guile: fix return value of static strings in API functions
  * irc: do not clear nicklist when joining an already joined channel if
    the option irc.look.buffer_open_before_join is on
  * irc: fix CTCP PING reply when the option irc.ctcp.ping is set to non-empty value
  * lua: fix boolean return value (as integer) in API functions
  * relay: fix parsing of CAP command without arguments in irc protocol, send ACK
    only if all capabilities received are OK and NAK otherwise
  * core: fix build with ncurses and separate tinfo
* Mon Sep 25 2017 tchvatal@suse.com
- Version update to 1.9.1:
  * Security update to fix CVE-2017-14727 bsc#1060140
* Sun Jun 25 2017 mimi.vx@gmail.com
- update to 1.9
  * improve speed of nicklist bar item callback
  * add auto scroll of buflist bar with new option buflist.look.auto_scroll
  * add option buflist.format.name
  * add variables ${format_name}, ${current_buffer} and ${merged}@@ in buflist
  * display a warning in buflist when the script buffers.pl is loaded
  * add server/channel pointers in trigger IRC callbacks
  * add API functions config_option_get_string and hdata_compare
  * fix bind of Space key
  * many bugs fixed.
  * buflist.format.name
  * buflist.look.auto_scroll
  * F1/F2: scroll buflist bar
* Mon May 15 2017 mimi.vx@gmail.com
- update to 1.8
  * add option weechat.completion.nick_case_sensitive
  * add wilcard matching operator, cut of string and ternary operator
    in evaluation of expressions
  * add resize of window parents with /window resize [h/v]size
  * add plugin "buflist" (bar with list of buffers)
  * add arraylist and dynamic string functions in API
  * add option "open" in command /server
  * add signal "irc_server_lag_changed" and store the lag
    in the server buffer (local variable)
  * add aspell options to control delimiters in suggestions
  * add option "-include" in commands /allchan, /allpv and /allserv
  * many bugs fixed.
* Sat Apr 22 2017 mimi.vx@gmail.com
- Update to version 1.7.1
  * irc: fix parsing of DCC filename CVE-2017-8073 (boo#1036467)
* Sun Jan 15 2017 mimi.vx@gmail.com
- Update to version 1.7
  * New features
    + core: add option weechat.look.align_multiline_words
    + core: add optional command prefix in completion templates "commands",
  "plugins_commands" and "weechat_commands"
    + core: add optional arguments in completion template, sent to the callback
    + core: add option "time" in command /debug
    + api: add info "uptime" (WeeChat uptime)
    + api: add info "pid" (WeeChat PID)
    + fifo: add file fifo.conf and option fifo.file.path to customize
  FIFO pipe path/filename
    + irc: add server option "usermode"
    + irc: add tag "self_msg" on self messages
  * Improvements
    + core, xfer: display more information on fork errors
    + core: add a slash before commands completed in arguments of /command,
  /debug time, /key bind, /key bindctxt, /mute, /repeat, /wait
    + core: add a warning in header of configuration files to not edit by hand
    + alias: add a slash before commands completed in arguments of /alias
    + exec: add option "-oc" in command /exec to execute commands in process
  output, don’t execute commands by default with "-o"
    + irc: evaluate content of server option "ssl_fingerprint"
    + irc: change default value of option irc.network.lag_reconnect from 0 to 300
    + trigger: do not hide email in command "/msg nickserv register password email"
  * Bug fixes
    + core: fix deadlock when quitting after a signal SIGHUP/SIGQUIT/SIGTERM
  is received
    + core: fix display of empty lines in search mode
    + api: fix crash in function string_expand_home() when the HOME environment
  variable is not set
    + exec: fix memory leak in display of process output
    + irc: fix option "-temp" in command /server
    + irc: fix close of server channels which are waiting for the JOIN when
  the server buffer is closed
    + irc: fix buffer switching on manual join for forwarded channels
    + irc: add missing tags on CTCP message sent
    + lua: fix integers returned in Lua >= 5.3
    + relay: make HTTP headers case-insensitive for WebSocket connections
    + relay: set status to "authentication failed" and close immediately
  connection in case of authentication failure in weechat and irc protocols
    + script: reload a script after upgrade only if it was loaded, set autoload
  only if the script was auto-loaded
* Sun Oct  2 2016 mimi.vx@gmail.com
- update to version 1.6
- removed weechat-doc subpackage, ( BuildRequires dep missing )
  * New features:
  + core: add optional argument "lowest", "highest" or level mask in command
    /input hotlist_clear
  + core: add option "cycle" in command /buffer
  + api: add "extra" argument to evaluate extra variables in function
    string_eval_expression()
  + relay: add option relay.network.allow_empty_password
  + trigger: add support for one-time triggers
  Improvements
  + core, irc, xfer: display more information in memory allocation errors
  + api: remove functions printf_date() and printf_tags()
  + irc: rename server options "default_msg_{kick|part|quit}" to
    "msg_{kick|part|quit}", evaluate them
  + relay: allow escape of comma in command "init" (weechat protocol)
  Bug fixes
  + core, irc, xfer: refresh domain name and name server addresses before
    connection to servers (fix connection to servers after suspend mode)
  + api: fix return of function string_match() when there are multiple masks
    in the string
  + api: fix crash in function network_connect_to() if address is NULL
  + api: fix connection to servers with hook_connect() on Windows 10 with
    Windows subsystem for Linux
  + api: fix crash in function string_split_command() when the separator
    is not a semicolon
  + irc: fix socket leak in connection to server
  + irc: fix display of service notice mask (message 008)
  + irc: fix NULL pointer dereference in 734 command callback
  + relay: return an empty hdata when the requested hdata or pointer is not found
  + xfer: fix crash on DCC send if option xfer.file.auto_accept_nicks is set
  Documentation
  + switch to asciidoctor to build docs and man page
* Tue Jun 14 2016 mimi.vx@gmail.com
- fix typo in %%if conditional
* Sun May 15 2016 mimi.vx@gmail.com
- update to 1.5
  * New features:
  + core: add Portuguese translations
  + core: change default value of option weechat.look.nick_color_hash to "djb2"
  + core: move nick coloring from irc plugin to core, move options
  irc.look.nick_color_force, irc.look.nick_color_hash and
  irc.look.nick_color_stop_chars to core, add info "nick_color" and
  "nick_color_name", deprecate info "irc_nick_color" and "irc_color_name"
  + core: move irc bar item "away" to core, move options irc.look.item_away_message
  and irc.color.item_away to core
  + api: add support of functions in hook_process
  + api: add pointer in callbacks used in scripting API
  + irc: add option irc.network.sasl_fail_unavailable
  + irc: add multiple targets and support of "-server" in command /ctcp
  + ruby: add detection of Ruby 2.3
  + trigger: add "recover" in default triggers cmd_pass/msg_auth, and "regain"
  in default trigger "msg_auth"
  * Bugs fixed:
  + core: fix nick coloring when stop chars and a forced color are used: first
  remove chars then look for forced color
  + core: check that pointers received in arguments are not NULL in buffers
  and windows functions
  + core: fix truncation of buffer names in hotlist
  + core: fix update of window title under Tmux
  + core: fix detection of Python shared libraries
  + api: fix number of arguments returned by function string_split() when
  keep_eol is 2 and the string ends with separators
  + irc: fix first message displayed in raw buffer when the message is modified
  by a modifier
  + irc: add missing completion "*" for target in command /msg
  + irc: fix /msg command with multiple targets including "*"
  + lua: fix crash when a lua function doesn’t return a value and a string
  was expected
  + relay: do not execute any command received in a PRIVMSG message from
  an irc relay client
  + relay: fix the max number of clients connected on a port, allow value
  0 for "no limit"
  + relay: fix decoding of multiple frames in a single websocket message, send
  PONG on PING received in a websocket frame
  + relay: fix command "input" received from clients with only spaces in content
  of message (weechat protocol)
  + script: force refresh of scripts buffer after download of scripts list
  + xfer: fix DCC file received when the terminal is resized
* Sun Mar 20 2016 bwiedemann@suse.com
- Fix build-compare
- include .changes file as Source so that .src.rpm can be rebuilt
* Thu Feb 18 2016 mimi.vx@gmail.com
- fix sle12 conditional
* Mon Jan 11 2016 mimi.vx@gmail.com
- add weechat.keyring and verify source tarball by gpg
* Sun Jan 10 2016 mimi.vx@gmail.com
- Version bump to 1.4
  + New features:
  * core: add a parent name in options, display inherited values if null in /set
  output, add option weechat.color.chat_value_null
  * core: add tag "term_warning" in warnings about wrong $TERM on startup
  * core: add option weechat.look.paste_auto_add_newline
  * core: display a more explicit error when a filter fails to be added
  * api: add function string_hex_dump()
  * api: add argument "length" in function utf8_is_valid()
  * alias: display completion in /alias list
  * fifo: add /fifo command
  * irc: evaluate content of server option "addresses"
  * irc: move option irc.network.alternate_nick into servers
  (irc.server.xxx.nicks_alternate)
  * irc: track real names using extended-join and WHO
  * irc: add support of SNI (Server Name Indication) in SSL connection
  to IRC server
  * irc: use current channel and current server channels first in completions
  "irc_server_channels" and "irc_channels"
  * irc: add support of "cap-notify" capability
  * irc: add command /cap
  * irc: add hex dump of messages in raw buffer when debug is enabled for irc
  plugin (level 2 or more)
  * logger: display system error when the log file can not be written
  * relay: add option relay.irc.backlog_since_last_message
  * script: add completion with languages and extensions, support search by
  language/extension in /script search
  * script: add option script.scripts.download_timeout
  * doc: add Czech man page and quickstart guide
  * tests: check if all plugins are loaded
  + Bugs fixed:
  * core: fix execution of empty command name ("/" and "/ " are not valid
  commands)
  * core: fix memory leak when using multiple "-d" or "-r" in command line
  arguments
  * core: don’t complain any more about "tmux" and "tmux-256color" $TERM values
  when WeeChat is running under tmux
  * core: fix truncated messages after a word with a length of zero on screen
  (for example a zero width space: U+200B)
  * api: fix handle of invalid escape in function string_convert_escaped_chars()
  * alias: do not allow slashes and spaces in alias name
  * irc: fix channel forwarding when option
  irc.look.buffer_open_before_{autojoin|join} is on
  * irc: add a missing colon before the password in PASS message, if the password
  has spaces or begins with a colon
  * irc: fix charset decoding in incoming private messages
  * irc: display the arrow before server name in raw buffer
  * irc: fix display of messages sent to server in raw buffer
  * irc: fix display of invalid UTF-8 chars in raw buffer
  * relay: display the arrow before client id and protocol in raw buffer
  * ruby: fix load of scripts requiring "uri"
  * ruby: fix Ruby detection when pkg-config is not installed
  * tests: fix locale used to execute tests
* Sun Aug 16 2015 mimi.vx@gmail.com
- Version bump to 1.3:
  * core: add completion "colors" (issue #481)
  * core: start/stop search in buffer at current scroll position by default, add
  key Ctrl+q to stop search and reset scroll (issue #76, issue #393)
  * core: add option weechat.look.key_grab_delay to set the default delay when
  grabbing a key with Alt+k
  * core: add option weechat.look.confirm_upgrade (issue #463)
  * core: allow Ctrl+c to exit WeeChat when the passphrase is asked on startup (issue #452)
  * core: allow pointer as list name in evaluation of hdata (issue #450)
  * core: add signal "signal_sighup"
  * api: add support of evaluated sub-strings and current date/time in function
  string_eval_expression() and command /eval
  * api: add function string_eval_path_home()
  * alias: add options "add", "addcompletion" and "del" in command /alias, remove
  command /unalias (issue #458)
  * irc: add option irc.network.channel_encode (issue #218, issue #482)
  * irc: add option irc.color.topic_current (issue #475)
  * irc: evaluate content of server option "nicks"
  * logger: evaluate content of option logger.file.path (issue #388)
  * relay: display value of HTTP header "X-Real-IP" for websocket connections (issue #440)
  * script: rename option script.scripts.dir to script.scripts.path, evaluate content
  of option (issue #388)
  * xfer: evaluate content of options xfer.file.download_path and xfer.file.upload_path (issue #388)
  * many bug fixes
* Tue Aug  4 2015 tchvatal@suse.com
- Ensure we use system CA ca-bundle.pem file by hardcoding it
- Remove patch:
  * weechat-capath.patch
* Sat Jul  4 2015 tchvatal@suse.com
- Version bump to 1.2:
  - add options to customize word chars (for detecting word boundaries)
  - add a welcome message on first WeeChat run
  - add options to customize quoted messages (in cursor mode)
  - add support of environment variables in evaluated expressions
  - add IRC SASL mechanism "ecdsa-nist256p-challenge"
  - add support of SHA-256 and SHA-512 algorithms in IRC server option "ssl_fingerprint"
  - add support of IRC capability "account-notify"
  - remove "freenode" server from default config
  - new script plugin for javascript
  - many bugs fixed.
- Refreshed patch:
  * weechat-capath.patch
* Mon Feb 16 2015 tchvatal@suse.com
- Version bump to 1.1.1:
  * core: fix random error when creating symbolic link weechat-curses on make install with cmake (bug #40313)
  * core: fix crash when a root bar has conditions different from active/inactive/nicklist (closes #317)
  * irc: don’t close channel buffer on second /part when option irc.look.part_closes_buffer is off (closes #313)
  * irc: fix /join on a channel buffer opened with autojoin but which failed to join
  * irc: send QUIT to server and no PART for channels when the server buffer is closed (closes #294)
  * irc: fix order of channel buffers opened when option irc.look.server_buffer is set to "independent", irc.look.buffer_open_before_autojoin to "on" and irc.look.new_channel_position to "near_server" (closes #303)
  * irc: fix crash in buffer close when server name is the same as a channel name (closes #305)
* Wed Jan 28 2015 tchvatal@suse.com
- Recommend lang package and perl/python scripting support as
  bare iron weechat is bit boring
* Wed Jan 28 2015 tchvatal@suse.com
- Make this build on SLE12
* Mon Jan 12 2015 tchvatal@suse.com
- Version bump to 1.1:
  - complete inline commands in input
  - allow incomplete commands if unambiguous
  - improve speed of completions
  - add bar item and signals for mouse status
  - use bar conditions on root bars
  - add option "reorder" in command /server
  - open irc channel buffers before the join is received from server
  - add server option "sasl_fail"
  - add support for color codes 16-99 in IRC messages
  - disable SSLv3 by default
  - add support of IRC capability "extended-join"
  - add options "stop" and "start" in command /relay
  - use HTTPS by default in script plugin for downloads
  - add option "restore" in command /trigger
  - evaluate and replace regex groups at same time in trigger (new and
    incompatible format)
  - many bugs fixed.
* Thu Nov 20 2014 tchvatal@suse.com
- Remove sle11 support as now I don't need it anymore
- Use %%cmake macro properly
- Document that there are tests that need extra pkg
- Split documentation into -doc subpackage
* Fri Oct 10 2014 gber@opensuse.org
- update toversion 1.0.1
  - this is a bug fix and maintenance release
  - for complete list of bugs fixed, please look at ChangeLog
* Sat Aug 16 2014 gber@opensuse.org
- update to version 1.0
  - plugin "trigger": Swiss Army knife for WeeChat (replaces
    "rmodifier" plugin)
  - plugin "exec": execute external commands (replaces script
    "shell.py")
  - bare display: easy click on long URLs and text selection with
    mouse
  - support of environment variables in /set command
  - hidden buffers
  - negated tags in filters
  - toggle of filters in specific buffers
  - flexible conditions for adding/removing buffers in hotlist
  - text search in buffers with free content
  - support of wildcard "*" inside masks
  - support of nested variables in evaluated expressions
  - tag with host in IRC messages displayed
  - support of "away-notify" IRC capability
  - IRC commands: /allpv, /remove, /unquiet
  - bar items: buffer_short_name, irc_nick_modes
  - unit tests
  - many bugs fixed
- drop obsolete weechat-link-pthread.patch
* Mon Jun 23 2014 tchvatal@suse.com
- Make the thing build again on SLE11 as we use it in SUSE on
  server :)
* Mon May 26 2014 gber@opensuse.org
- update to version 0.4.3
  - new command /print
  - logical and/or for tags in /filter and hook_print
  - gaps in buffer numbers
  - support of italic text
  - new options to customize default text search in buffers
  - use of IRC monitor command for /notify (if available on server)
  - new IRC server option "ssl_fingerprint"
  - new option to smart-filter IRC mode messages
  - new option for default IRC ban mask
  - support of IPv6 for DCC chat/file
  - auto check CRC32 of files received with DCC
  - many bugs fixed
- add weechat-link-pthread.patch in order to link Weechat against
  libpthread fixing freezes/crashes with gnutls (backported from
  upstream git)
* Mon Oct  7 2013 gber@opensuse.org
- remove support for < 12.2
* Mon Oct  7 2013 gber@opensuse.org
- update to version 0.4.2
  * rename binary from "weechat-curses" to "weechat" (with symbolic
    link "weechat-curses" for compatibility)
  * add secured data (encryption of passwords or private data), new
    command /secure, new file sec.conf
  * search of regular expression in buffer with text emphasis, in
    prefixes, messages or both
  * add option "scroll_beyond_end" for command /window
  * add optional buffer context in bar items (for example to
    display bitlbee nicklist in a root bar)
  * new options weechat.look.hotlist_{prefix|suffix}
  * new option weechat.look.key_bind_safe to prevent any key
    binding error from user
  * new option weechat.network.proxy_curl to use a proxy when
    downloading URLs with curl
  * display day change message dynamically
  * support of wildcards in IRC commands (de)op/halfop/voice
  * new option irc.look.notice_welcome_redirect to redirect channel
    welcome notices to the channel buffer
  * new option irc.look.nick_color_hash: new hash algorithm to find
    nick colors (variant of djb2)
  * add info about things defined by a script in the detailed view
    of script (/script show)
  * support of "enchant" library in aspell plugin
  * many bugs fixed.
- rebased weechat-0.4.1-capath.diff and renamed to
  weechat-capath.patch
- build aspell plugin with enchant support
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Tue Aug  6 2013 lnussel@suse.de
- use system's default certificate store instead of hardcoding the
  path to a bundle file (weechat-0.4.1-capath.diff, bnc#829471)
* Tue May 21 2013 gber@opensuse.org
- update to version 0.4.1
  * multiple layouts support
  * nick prefix/suffix are now dynamic (and managed by core instead
    of irc plugin)
  * unmask irc join if nick speaks some minutes after the join
  * new option irc.look.display_join_message to disable some
    messages after joining a channel
  * new option irc.look.pv_buffer to automatically merge private
    buffers
  * add support of UHNAMES
  * add DH-AES encryption method for SASL
  * multiple irc servers allowed on same port for irc protocol in
    relay plugin
  * add WebSocket server support (RFC 6455) in relay plugin (for
    irc and weechat protocols)
  * send nicklist difference in relay plugin (weechat protocol)
  * add control of autoload for scripts
  * optimizations in aspell plugin
  * many bugs fixed.
* Mon Jan 21 2013 tchvatal@suse.com
- Version bump to version 0.4.0:
  * add option "diff" for command /set, display default values in output of /set
  * add color support in prefix options
  * add command /eval, use expression in conditions for bars
  * connect by default with IPv6 to servers with fallback to IPv4
  * add aspell suggestions
  * add support of tags in irc messages and "server-time" capability
  * add irc command /quiet
  * add support of IPv6 in relay plugin
  * add backlog for irc protocol in relay plugin
  * display remote IP address for DCC chat/file in xfer plugin
  * add git version in build
  * many bugs fixed.
* Mon Nov 19 2012 gber@opensuse.org
- update to version 0.3.9.2:
  * fix possible shell injection vulnerability in hook_process
    function (bnc#790217)
* Sat Nov 10 2012 gber@opensuse.org
- update to version 0.3.9.1:
  * fix buffer overflow when decoding IRC colors in strings
* Sun Sep 30 2012 gber@opensuse.org
- update to version 0.3.9:
  * add plugin "script" (replacement of weeget.py and script.pl)
  * add support of SSL in relay plugin
  * add color for offline nicks
  * add system resource limits for WeeChat process
  * add zoom on merged buffer (default key: alt+"x")
  * add "Day changed to" in logger backlog
  * add command line option "-r" (or "--run-command") to run
    command(s) after startup of WeeChat
  * add option "swap" for command /buffer
  * generate alternate IRC nicks dynamically (when all nicks are
    already in use)
  * fix rejoin of password protected IRC channels
  * fix freeze in irc and relay plugins with sockets
  * allow update for some variables of hdata
  * add japanese user's guide, scripting guide and tester's guide
  * many bugs fixed
- drop obsolete weechat-fix-cmake-guile.patch
* Mon Jun  4 2012 gber@opensuse.org
- enable guile scripting support introduced in 0.3.7
- dropped unnecessary weechat-0.3.3-fix-strftime.patch
- added weechat-fix-cmake-guile.patch which fixes the include dir
  for guile no being passed to the guild script plugin cmake file
* Mon Jun  4 2012 gber@opensuse.org
- update to version 0.3.8:
  * add terminal "bracketed paste mode"
  * add IRC "external" SASL mechanism
  * improve parsing of IRC channel modes (do not send extra command
    "MODE" to server)
  * follow symbolic links for configuration files (*.conf)
  * new option weechat.look.prefix_same_nick (hide same prefix for
    multiple consecutive messages from same nick)
  * add colors for backlog lines
  * redirect IRC messages from clients to hide output (relay
    plugin, IRC protocol)
  * add a connection timeout for child process in hook_connect
  * fix display bugs and crashs with small windows
  * fix truncated configuration files (zero-length) after system
    crash
  * many bugs fixed.
* Mon May 21 2012 badshah400@gmail.com
- Use BuildRequires: libgnutls-devel instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Sun Feb 26 2012 pascal.bleser@opensuse.org
- update to 0.3.7:
  * adds support for scheme scripts (with GNU guile)
  * adds support for Python 3.x
  * adds remote interfaces using a relay plugin (like QWeeChat, a Python/Qt remote interface)
  * adds URL transfers in the API
  * option `scroll_unread` has been moved from command `/input` to `/window`,
    therefore default command of key alt-u has been updated. To bind key with
    new default value: `/key bind meta-u /window scroll_unread`
  * extended regex is used in filters and irc ignore, so some chars that needed
    escape in past do not need any more (for example `[0-9]\+` becomes
    `[0-9]+`), filters and ignore have to be manually fixed
  * option 'weechat.look.highlight_regex' becomes case insensitive by default,
    to make it case sensitive, use "(?-i)" at beginning of string, for example:
    "(?-i)FlashCode|flashy"
  * option 'weechat.history.max_lines' has been renamed to
    'weechat.history.max_buffer_lines_number'
* Sun Jan  8 2012 gber@opensuse.org
- clean up build dependencies
- build against lua51 for > 12.1
* Fri Dec  9 2011 coolo@suse.com
- the COPYING says GPL-3.0+
* Sun Oct 23 2011 gber@opensuse.org
- removed weechat-remove_build_timestamp.patch and use previous
  code again to deal with timestamps
* Sat Oct 22 2011 pascal.bleser@opensuse.org
- update to 0.3.6:
  * mouse support
  * cursor mode (free movement of cursor on screen)
  * contexts for keys (default, search, cursor, mouse)
  * hdata in API (direct access to WeeChat data)
  * "inactive" colors for inactive windows and lines in merged
    buffers
  * support of merged buffers in /layout, save layout of
    buffers/windows on /upgrade
  * horizontal scrolling in buffers with free content
  * split of outgoing IRC messages
  * options for "more" chars in bars
  * bold not used any more for basic colors (if terminal has more
    than 16 colors)
  * automatic zoom on current window when terminal becomes too
    small for windows
  * new command /repeat
  * local variable "highlight_regex" in buffers
- added weechat-remove_build_timestamp.patch
* Mon May 16 2011 gber@opensuse.org
- update to version 0.3.5:
  * 256 colors support improved (dynamic allocation of colors)
  * attributes for colors (bold/reverse/underline)
  * better scroll of input (with long text)
  * output of /help improved for list of commands and their
    arguments
  * remember scroll position of buffers in windows
  * list of buffers in filters
  * count of messages in hotlist buffers
  * swap buffers of windows
  * balance of windows
  * new API function to set help on plugin/script options
  * speller options in aspell plugin
  * option for SSL priorities in IRC servers
  * color nicks in nicklist and output of /names
- dropped weechat-0.3.4-fix-array-overflow.patch which has been
  included upstream
* Wed Mar 23 2011 gber@opensuse.org
- dropped weechat-0.3.4-remove-date-time.patch, use date/time from
  last changelog entry rather than removing it completely
- use %%desktop_database_post/un
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Thu Feb 17 2011 gber@opensuse.org
- added weechat-0.3.4-fix-array-overflow.patch which fixes an
  array overflow
* Sun Jan 16 2011 pascal.bleser@opensuse.org
- update to 0.3.4:
  * adds 256-color support
  * adds IRC proxy support
  * adds redirection of IRC commands
  * adds new /notify command
  * adds the rmodifier plugin
  * adds regular expression support for highlights
  * adds sharing of the input line between buffers
  * many bugfixes
* Mon Nov  8 2010 gber@opensuse.org
- cleanup
  * added specfile header
  * added more accurate summary and description
  * removed support for obsolete openSUSE versions
  * split off -lang subpackage
  * added patch to remove __DATE__ and __TIME__ macros
  * enabled make output
  * build with $RPM_OPT_FLAGS
* Mon Oct 11 2010 gber@opensuse.org
- fixed build for Python > 2.6
* Sun Aug  8 2010 pascal.bleser@opensuse.org
- update to 0.3.3:
  * new features:
    + keys to undo/redo changes on the command line
    + a better lag indicator
    + the /wallchops IRC command
    + display of messages in IRC private buffers when the nick is back on a server after a /quit
    + reverse regex in a filter
    + hash tables in the plugin API
  * many bugfixes
* Sun Apr 18 2010 pascal.bleser@opensuse.org
- update to 0.3.2:
  * add SASL authentication with IRC servers
  * add new commands /mute and /map
  * add custom completion for aliases
  * add date format in log filenames
  * autoloading of plugins was improved
  * many bugs were fixed
* Sun Jan 31 2010 pascal.bleser@opensuse.org
- update to 0.3.1.1:
  * fixes crashes with SSL connection and purge of old DCC chats
* Sat Jan 23 2010 pascal.bleser@opensuse.org
- update to 0.3.1:
  * new features
  * options were added to customize CTCP replies and the target
    buffer for IRC messages
  * SSL certificates are now checked
  * CertFP was added for automatic identification on servers
  * anti-flood measures were improved
  * new expansions were added for alias arguments
  * many bugs were fixed
* Sun Sep 13 2009 pascal.bleser@opensuse.org
- update to 0.3.0:
  * externalization of IRC as a plugin
  * new display engine (faster)
  * NES plugins
  * new plugin API
  * buffers with free content
  * dynamic filtering
  * smart join/part/quit filter
  * custom bars with custom items
  * buffer merging
  * group support in nicklist
  * less CPU usage
* Fri Jun 12 2009 pascal.bleser@opensuse.org
- update to 0.2.6.3:
  * fixes a bug with detection of the gnutls library
* Sat Apr 18 2009 pascal.bleser@opensuse.org
- update to 0.2.6.2:
  * fixes a charset decoding problem
* Mon Mar 16 2009 pascal.bleser@opensuse.org
- update to 0.2.6.1:
  * fixes a crash with some special characters in IRC messages
* Wed Sep  5 2007 guru@unixtech.be
- update to 0.2.6
* Fri Jun  8 2007 guru@unixtech.be
- initial build service submission
